from httpx import stream

import utils,json,requests
import re  # 添加正则表达式库

class FastGPTAi:

    def __init__(self, api_key: str=None, api_url: str=None):
        self._api_key = api_key or utils.get_config_value('fastgpt.api_key')
        self._api_url = api_url or utils.get_config_value('fastgpt.api_url')
        self._logger = utils.get_logger()
        self._headers ={}

    def call_ai(self, msg: str) -> json:
        try:
            if self._api_key is None:
                self._logger.error("fastgpt.api_key 没有配置")
                raise Exception("fastgpt.api_key 没有配置")

            self._headers = {
                "Authorization": f"Bearer {self._api_key}",
                "Content-Type": "application/json"
            }
            url = f"{self._api_url}/v1/chat/completions"
            data = {
                # "model":"",
                "stream": False,
                "detail": False,
                "messages": [
                    {
                        "role": "user",
                        "content": msg
                    }
                ],
                "response_format": {
                    "type": "json_object"
                }
            }

            response = requests.post(url, headers=self._headers, json=data)
            if response.status_code == 200:
                result = response.json()
                self._logger.info(f"Response: {result}")
                content = result.get("choices", [{}])[0].get("message", {}).get("content", "")
                if content:
                    # 使用正则表达式去除 content 前后的特定字符串
                    content = re.sub(r'^```json\n', '', content.strip())
                    content = re.sub(r'\n```$', '', content.strip())
                    try:
                        data = json.loads(content)
                        self._logger.info(f"Response_JSON: {data}")
                        return data
                    except json.JSONDecodeError as e:
                        self._logger.error(f"Failed to decode JSON: {e}")
                        return None
                return None
            else:
                error_msg = f"Error: {response.status_code} - {response.text}"
                self._logger.error(error_msg)
                return None
        except Exception as e:
            self._logger.error(f"Error: {str(e)}")
            return None
