import utils
from pathlib import Path

from stores.mysql_store import MysqlStore
from models.standard_data import StandardModel
import pandas as pd  # 添加对pandas库的导入，用于处理表格数据

class StandardDataProcess:
    def __init__(self):
        self._logger= utils.get_logger()
        self._store= MysqlStore()
        self._ai_helper = utils.AiHelper()
        self._ai_sys_prompt = "查询给定数据的标准编号信息，返回压缩的json字符传"

    def run(self,version:str):
        path= f"./temp_files/data/v{version}"
        data = self.read_excels(path)
        self.insert_data(version,data)

    def read_excels(self, folder_path:str):
        path = Path(folder_path)
        # 验证路径是否存在
        if not path.exists():
            raise FileNotFoundError(f"目录不存在: {path.resolve()}")

        # 验证是否是目录
        if not path.is_dir():
            raise NotADirectoryError(f"路径不是目录: {path.resolve()}")

        excel_files = list(path.glob('.csv'))
        for file in excel_files:
            try:
                # 读取CSV文件
                df = pd.read_csv(file)
                data =  df.to_dict(orient='records')
                return data
            except Exception as e:
                self._logger.error(f"读取数据失败 {file}: {str(e)}")

    def insert_data(self,version:str,data):
        for row in data:
            standard_no = row['电算代号']
            if not standard_no:
                continue
            name = row['项目名称']
            unit = row['单位']
            item = self._store.query_standard_data_by_no(row['电算代号'],version)
            if item:
                item.standard_version=version
                item.standard_name=name
                item.device_model=None
                item.device_unit=unit
                self._store.update_standard_data(item)
            else:
                item= StandardModel(device_name=name, device_unit=unit, standard_no=standard_no, standard_version=version)
            self._store.insert_standard_data(item)
