import  utils
from stores.mysql_store import MysqlStore
from models.project_data import ProjectModel, ProjectItemModel


class DataSend:
    def __init__(self):
        self._logger= utils.get_logger()
        self._store= MysqlStore()

    def send_by_project(self, project: ProjectModel) -> bool:
        try:

            self._logger.info(f"开始发送数据，项目：{project.project_no}")
            self._store.update_project_status(project.id,23)
            data_list = self._store.query_project_items_by_project(project.id, with_empty=False)
            for data in data_list:
                self.send_data(data)
            self._store.update_project_status(project.id,33)
            self._logger.info(f"发送数据成功，项目：{project.project_no} 共发送{len(data_list)}条")
            return True
        except Exception as e:
            self._logger.error(f"发送数据失败，项目：{project.project_no}，错误信息：{e}")
            self._store.update_project_status(project.id,13)
            return False

    def send_by_item_id(self, item_id: int) -> bool:
        try:
            self._logger.info(f"开始发送数据，项目：{item_id}")
            data = self._store.query_project_item_by_id(item_id)
            if self.send_data(data):
                self._logger.info(f"发送数据成功，项目：{item_id}")
                return True
            return False
        except Exception as e:
            self._logger.error(f"发送数据失败，项目：{item_id}，错误信息：{e}")
            return False

    def send_data(self, data: ProjectItemModel) -> bool:
        try:
            self._logger.debug(f"开始远程请求发送数据，数据：{data}" )
        except Exception as e:
            self._logger.error(f"发送数据失败，数据：{data}，错误信息：{e}")
            return False