from flask import render_template, url_for, redirect, request, jsonify
from flask import Blueprint
import os,utils

from .project_services import SourceDataService
from models.project_data import ProjectModel,ProjectItemModel

SourceDataService = SourceDataService()  # 确保 SourceDataService 是一个实例

# 创建一个名为 'project' 的蓝图
project = Blueprint('project', __name__, template_folder='templates/project')

@project.route('/')
def index():
    return "Hello, World!"

@project.route('/project_list')
def project_list():
    keyword = request.args.get('k', '', type=str)
    page = request.args.get('p', 1, type=int)
    per_page = request.args.get('pp', 15, type=int)
    status = request.args.get('s',-1, type=int)
    data_list, total_count = SourceDataService.get_all_project_paginated(page, per_page, keyword, None if status == -1 else status)  # 传递 status 参数
    return render_template('project_list.html', project_list=data_list, keyword=keyword, page=page, per_page=per_page, total_count=total_count, status=status)  # 传递 status 参数到模板

@project.route('/project_item_list/<project_id>')
def project_item_list(project_id:int):
    keyword = request.args.get('k', '', type=str)
    page = request.args.get('p', 1, type=int)
    per_page = request.args.get('pp', 15, type=int)
    project_data= SourceDataService.get_project_by_id(project_id)
    project_items, total_count = SourceDataService.get_project_item_list_by_project_paginated(project_id, page, per_page, keyword)
    return render_template('project_item_list.html', project=project_data, project_items=project_items, keyword=keyword, page=page, per_page=per_page, total_count=total_count)

@project.route('/save_project', methods=['POST'])
def save_project():
    project_id = request.form.get('id')
    project_no = request.form.get('project_no')
    if not project_no:
        return jsonify({'success': False, 'error': 'ProjectNo不能为空'}), 400
    project_name = request.form.get('project_name')
    standard_version = request.form.get('standard_version')
    work_catalog = request.form.get('work_catalog')
    work_content = request.form.get('work_content')
    delete_old_data = request.form.get('delete_old_data') == 'true'
    # 处理多文件上传
    project_files = request.files.getlist('project_files')
    project_data = None
    if project_id:
        project_data = SourceDataService.get_project_by_id(int(project_id))
    if len(project_files)<=0 and project_id and delete_old_data:
        return jsonify({'success': False, 'error': '请上传项目数据文件'}), 400
    elif project_files:
        try:
            base_path = os.path.abspath(utils.get_config_value("file.source_path","./temp_files"))
            if not os.path.exists(base_path):
                os.makedirs(base_path)
            # 如果选择删除旧数据且目录存在，则删除目录下的所有文件
            if delete_old_data and project_data :
                del_path = os.path.join(base_path, f"project/{project_data.project_no}")
                if os.path.exists(del_path):
                    for filename in os.listdir(del_path):
                        file_path = os.path.join(del_path, filename)
                        try:
                            if os.path.isfile(file_path):
                                os.remove(file_path)
                        except Exception as e:
                            return jsonify({'success': False, 'error': f'删除旧文件失败：{str(e)}'}), 500
            path = os.path.join(base_path, f"project/{project_no}")
            if not os.path.exists(path):
                os.makedirs(path)
            for project_file in project_files:
                filename = project_file.filename
                if filename and '.' in filename:
                    file_ext = filename.rsplit('.', 1)[1].lower()
                    if file_ext not in {'xlsx', 'xls', 'csv'}:
                        return jsonify({'success': False, 'error': f'不支持的文件格式：{filename}，请上传xlsx,xls,csv文件'}), 400
                    file_path = os.path.join(path, filename)
                    project_file.save(file_path)
                    
        except PermissionError:
            return jsonify({'success': False, 'error': '文件保存失败：权限不足，请确保应用程序具有写入权限'}), 403
        except Exception as e:
            return jsonify({'success': False, 'error': f'文件保存失败：{str(e)}'}), 500
    elif not project_id:
        return jsonify({'success': False, 'error': '请上传项目数据文件'}), 400

    if project_data:
        project_data.project_no = project_no
        project_data.project_name = project_name
        project_data.standard_version = standard_version
        project_data.work_catalog = work_catalog
        project_data.work_content = work_content
        SourceDataService.update_project(project_data)
    else:
        project_data = ProjectModel(project_no=project_no,
                                    project_name=project_name,
                                    standard_version=standard_version,
                                    work_catalog=work_catalog,
                                    work_content=work_content,
                                    status=0)
        SourceDataService.add_project(project_data)
    return jsonify({'success': True})

@project.route('/update_project', methods=['POST'])
def update_project():
    req = request.get_json()
    project_id = req.get('id')
    project_no = req.get('project_no')
    project_name= req.get('project_name')
    standard_version= req.get('standard_version')
    work_catalog = req.get('work_catalog')
    work_content = req.get('work_content')
    project_data = SourceDataService.get_project_by_id(project_id)
    if not project_data:
        return jsonify({'success': False, 'error': '项目不存在'}), 404
    data= ProjectModel(project_id=project_id,
                       project_no=project_no,
                       project_name=project_name,
                       standard_version=standard_version,
                       work_catalog=work_catalog,
                       work_content=work_content,
                       status=project_data.status)
    SourceDataService.update_project(data)
    return jsonify({'success': True})

@project.route('/start_project_task/<project_id>', methods=['POST'])
def start_project_task(project_id:int):
    result, err_msg = SourceDataService.start_task(project_id)
    return jsonify({'success': result, 'error': err_msg})

@project.route('/process_project/<project_id>', methods=['POST'])
def process_project(project_id:int):
    result, err_msg = SourceDataService.process_project(project_id)
    return jsonify({'success': result, 'error': err_msg})
@project.route('/send_project/<project_id>', methods=['POST'])
def send_project(project_id:int):
    result, err_msg = SourceDataService.start_send_data(project_id)
    return jsonify({'success': result, 'error': err_msg})
@project.route('/delete_project/<project_id>', methods=['POST'])
def delete_project(project_id:int):
    result, err_msg =  SourceDataService.delete_project(project_id)
    return jsonify({'success': result, 'error': err_msg})

@project.route('/add_project_item', methods=['POST'])
def add_project_item():
    data = request.get_json()
    project_id = data.get('project_id')
    device_name = data.get('device_name')
    device_model = data.get('device_model')
    device_unit = data.get('device_unit')
    device_count = data.get('device_count')
    standard_no = data.get('standard_no')
    new_item = ProjectItemModel(project_id=project_id, device_name=device_name, device_model=device_model, device_unit=device_unit, standard_no=standard_no)
    item_id = SourceDataService.add_project_item(new_item)
    return jsonify({'success': True, 'id': item_id})

@project.route('/update_data_item', methods=['POST'])
def update_data_item():
    data = request.get_json()
    item_id = data.get('id')
    if not item_id:
        return jsonify({'success': False, 'error': 'ID 不能为空'}), 400
    device_name = data.get('device_name')
    device_model = data.get('device_model')
    device_unit = data.get('device_unit')
    device_count = data.get('device_count')
    standard_no = data.get('standard_no')
    # if not standard_no:
    #     return jsonify({'success': False, 'error': 'Standard No is missing'}), 400
    item =ProjectItemModel(item_id=item_id,project_id=project_id, device_name=device_name, device_model=device_model, device_unit=device_unit, standard_no=standard_no)
    SourceDataService.update_project_item(item)
    return jsonify({'success': True})

@project.route('/delete_project_item/<item_id>', methods=['POST'])
def delete_project_item_route(item_id):
    project_item = SourceDataService.get_project_item_by_id(item_id)
    SourceDataService.delete_project_item(item_id)
    return redirect(url_for('project.project_item_list', project_no=project_item.project_id))



